@@ -1,5 +1,5 @@
 /* client-callback.c --- Example SASL client, with callback for user info.
- * Copyright (C) 2004, 2005, 2007  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2007, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -26,7 +26,7 @@
 #include <gsasl.h>
 
 static void
-client_authenticate (Gsasl * ctx, Gsasl_session * session)
+client_authenticate (Gsasl_session * session)
 {
   char buf[BUFSIZ] = "";
   char *p;
@@ -39,15 +39,15 @@ client_authenticate (Gsasl * ctx, Gsasl_session * session)
       printf ("Input base64 encoded data from server:\n");
       fgets (buf, sizeof (buf) - 1, stdin);
       if (buf[strlen (buf) - 1] == '\n')
-	buf[strlen (buf) - 1] = '\0';
+        buf[strlen (buf) - 1] = '\0';
 
       rc = gsasl_step64 (session, buf, &p);
 
       if (rc == GSASL_NEEDS_MORE || rc == GSASL_OK)
-	{
-	  printf ("Output:\n%s\n", p);
-	  free (p);
-	}
+        {
+          printf ("Output:\n%s\n", p);
+          free (p);
+        }
     }
   while (rc == GSASL_NEEDS_MORE);
 
@@ -80,7 +80,7 @@ client (Gsasl * ctx)
     }
 
   /* Do it. */
-  client_authenticate (ctx, session);
+  client_authenticate (session);
 
   /* Cleanup. */
   gsasl_finish (session);
