@@ -1,5 +1,5 @@
 /* client.c --- Example SASL client.
- * Copyright (C) 2004, 2005, 2007  Simon Josefsson
+ * Copyright (C) 2004, 2005, 2007, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -26,7 +26,7 @@
 #include <gsasl.h>
 
 static void
-client_authenticate (Gsasl * ctx, Gsasl_session * session)
+client_authenticate (Gsasl_session * session)
 {
   char buf[BUFSIZ] = "";
   char *p;
@@ -40,20 +40,20 @@ client_authenticate (Gsasl * ctx, Gsasl_session * session)
       rc = gsasl_step64 (session, buf, &p);
 
       if (rc == GSASL_NEEDS_MORE || rc == GSASL_OK)
-	{
-	  /* If sucessful, print it. */
-	  printf ("Output:\n%s\n", p);
-	  free (p);
-	}
+        {
+          /* If sucessful, print it. */
+          printf ("Output:\n%s\n", p);
+          free (p);
+        }
 
       if (rc == GSASL_NEEDS_MORE)
-	{
-	  /* If the client need more data from server, get it here. */
-	  printf ("Input base64 encoded data from server:\n");
-	  fgets (buf, sizeof (buf) - 1, stdin);
-	  if (buf[strlen (buf) - 1] == '\n')
-	    buf[strlen (buf) - 1] = '\0';
-	}
+        {
+          /* If the client need more data from server, get it here. */
+          printf ("Input base64 encoded data from server:\n");
+          fgets (buf, sizeof (buf) - 1, stdin);
+          if (buf[strlen (buf) - 1] == '\n')
+            buf[strlen (buf) - 1] = '\0';
+        }
     }
   while (rc == GSASL_NEEDS_MORE);
 
@@ -91,7 +91,7 @@ client (Gsasl * ctx)
   gsasl_property_set (session, GSASL_PASSWORD, "secret");
 
   /* Do it. */
-  client_authenticate (ctx, session);
+  client_authenticate (session);
 
   /* Cleanup. */
   gsasl_finish (session);
