@@ -1,5 +1,5 @@
 /* login.h --- Prototypes for non-standard SASL mechanism LOGIN.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -29,8 +29,7 @@
 
 extern Gsasl_mechanism gsasl_login_mechanism;
 
-extern int _gsasl_login_client_start (Gsasl_session * sctx,
-				      void **mech_data);
+extern int _gsasl_login_client_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_login_client_step (Gsasl_session * sctx,
 				     void *mech_data,
 				     const char *input, size_t input_len,
@@ -38,8 +37,7 @@ extern int _gsasl_login_client_step (Gsasl_session * sctx,
 extern void _gsasl_login_client_finish (Gsasl_session * sctx,
 					void *mech_data);
 
-extern int _gsasl_login_server_start (Gsasl_session * sctx,
-				      void **mech_data);
+extern int _gsasl_login_server_start (Gsasl_session * sctx, void **mech_data);
 extern int _gsasl_login_server_step (Gsasl_session * sctx,
 				     void *mech_data,
 				     const char *input, size_t input_len,
